﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;

namespace WpfApplication1
{
    public abstract class BaseViewModel : INotifyPropertyChanged
    {
        #region INotifyPropertyChanged Implementation
        public event PropertyChangedEventHandler PropertyChanged;
        protected void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
        #endregion
    }

    public class MainWindowViewModel : BaseViewModel
    {
        private BaseViewModel _currentPageViewModel;
        public BaseViewModel CurrentPageViewModel
        {
            get { return _currentPageViewModel; }
            set
            {
                if (_currentPageViewModel != value)
                {
                    _currentPageViewModel = value;
                    OnPropertyChanged("CurrentPageViewModel");
                }
            }
        }

        private ReportsViewModel _reports;
        private LogsViewModel _logs;

        public MainWindowViewModel()
        {
            _reports = new ReportsViewModel();
            _logs = new LogsViewModel();

            CurrentPageViewModel = _logs;
        }

        public void ChangeToLogs()
        {
            CurrentPageViewModel = _logs;
        }
        public void ChangeToReports()
        {
            CurrentPageViewModel = _reports;
        }
    }

    public class LogsViewModel : BaseViewModel
    {

    }

    public class ReportsViewModel : BaseViewModel
    {

    }
}
